cheesecake.cheesecake_index.StepByVariable

Package cheesecake :: Module cheesecake_index :: Class StepByVariable |
[show private | hide private]
[frames | no frames]

## Type StepByVariable

    object --+
             |
          Step --+
                 |
                StepByVariable

Step which is always run if given Cheesecake instance variable is true.

Method Summary
| `__init__(self, variable_name, provides)`
| ``decide`(self, cheesecake)` Decide if step should be run.
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Method Details

### decide(self, cheesecake) Decide if step should be run. It checks if there's at least one index from current profile that need variables provided by this step. Override this method for other behaviour. Overrides: `cheesecake.cheesecake_index.Step.decide` (inherited documentation)

Generated by Epydoc 2.1 on Fri Feb 9 02:15:13 2007 | http://epydoc.sf.net